@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from data_visualization_models.cell import Cell
+from data_visualization_models.cell.cell import Cell
 
 class TextCell(Cell):
     pass
\ No newline at end of file
