@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from semantyk.data_visualization_models.graph import Graph
+from data_visualization_models.graph.graph import Graph
 
 class VennDiagram(Graph):
     pass
\ No newline at end of file
